from __future__ import print_function
from django.core import management


def initproject(args):
    """
    Initializes Django Hizashi project
    """
    print(
        'Initializing Django Hizashi project... {}'
        .format(args.project_name),
        end='')

    management.call_command(
        'startproject', args.project_name,
        template=args.template,
        extensions=['.py', '.rst'], verbosity=0)

    print(' ...done')


def initapp(args):
    """
    Initializes Django Hizashi application
    """
    print(
        'Initializing Django Hizashi application... {}'
        .format(args.application_name),
        end='')

    management.call_command(
        'startapp', args.application_name,
        template=args.template,
        verbosity=0)

    print(' ...done')
    print(
        '\nAdd \'{}\' to INSTALLED_APPS in \'core/settings/project.py\''
        .format(args.application_name))



#!/usr/bin/env python
import argparse

from hizashi_utils import modules

parser = argparse.ArgumentParser(description='Execute Hizashi utilities')
subparsers = parser.add_subparsers(title='Subcommands')


# initproject options
parser_initproject = subparsers.add_parser(
    'initproject', help='Initializes Django Hizashi project'
)
parser_initproject.add_argument(
    'project_name', type=str, help='Django Project name')
parser_initproject.add_argument(
    '--template', type=str, help='Django Project template folder/archive',
    default=(
        'https://github.com/dodobas/hizashi-project-template/archive/'
        'master.zip')
)
parser_initproject.set_defaults(func=modules.initproject)

# initapp options
parser_initapp = subparsers.add_parser(
    'initapp', help='Initializes Django Hizashi application'
)
parser_initapp.add_argument(
    'application_name', type=str, help='Application name')
parser_initapp.add_argument(
    '--template', type=str, help='Application template folder/archive',
    default=(
        'https://github.com/dodobas/hizashi-application-template/archive/'
        'master.zip')
)
parser_initapp.set_defaults(func=modules.initapp)

if __name__ == "__main__":
    # parse the args, and call default function
    args = parser.parse_args()
    args.func(args)



# -*- coding: utf-8 -*-
from setuptools import setup, find_packages


def readme():
    with open('README.rst') as f:
        return f.read()

setup(
    name='hizashi-utils',
    version='0.2.0',
    author='Dražen Odobašić',
    author_email='dodobasic@gmail.com',
    packages=find_packages(),
    include_package_data=True,
    scripts=['hizashi_utils/bin/hizashi.py'],
    url='https://github.com/dodobas/hizashi-utils',
    keywords='django hizashi utils helpers',
    license='LICENSE.txt',
    description='Utils for managing Django Hizashi environment',
    long_description=readme(),
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Console',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 2.7',
        'Topic :: Utilities'
    ],
    setup_requires=[
        "setuptools_git >= 0.3"
    ],
    install_requires=[
        "Django >= 1.5"
    ]
)
